/* gulpfile.js
 * Originally created 11/13/2018 by sapeck
 *
 * Copyright 2018-present sapeck
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const gulp = require('gulp')
const del = require('del')
const lec = require('gulp-line-ending-corrector')
const babel = require('gulp-babel')
const eslint = require('gulp-eslint')
const sourcemaps = require('gulp-sourcemaps')

gulp.task('check', () => {
  return gulp.src(['lib/**/*.js', 'bin/**/*.js', 'gulpfile.js'])
    .pipe(eslint())
    .pipe(eslint.format())
    .pipe(eslint.failAfterError())
})

gulp.task('checkSafe', () => {
  return gulp.src(['lib/**/*.js', 'bin/**/*.js', 'gulpfile.js'])
    .pipe(eslint())
    .pipe(eslint.format())
})

gulp.task('static', () => {
  return gulp.src('lib/**/*.js')
    .pipe(lec())
    .pipe(gulp.dest('lib'))
})

gulp.task('clean', (callback) => {
  del(['dist/*']).then(() => {
    callback()
  })
})

gulp.task('compile', gulp.parallel(() => {
  return gulp.src('lib/**/*.js')
    .pipe(sourcemaps.init())
    .pipe(babel({ presets: [ ['@babel/env', { targets: { node: '8' } }] ] }))
    .pipe(sourcemaps.write('.'))
    .pipe(gulp.dest('dist/lib'))
}, () => {
  return gulp.src(['lib/**/*', '!lib/**/*.js'])
    .pipe(gulp.dest('dist/lib'))
}, () => {
  return gulp.src('bin/**/*.js')
    .pipe(sourcemaps.init())
    .pipe(babel({ presets: [ ['@babel/env', { targets: { node: '8' } }] ] }))
    .pipe(sourcemaps.write('.'))
    .pipe(gulp.dest('dist/bin'))
}, () => {
  return gulp.src(['bin/**/*', '!bin/**/*.js'])
    .pipe(gulp.dest('dist/bin'))
}))

gulp.task('dist', gulp.series('static', 'check', 'clean', 'compile'))
gulp.task('build', gulp.series('static', 'checkSafe', 'compile'))

gulp.task('watch', gulp.series('checkSafe', 'clean', 'compile'))
//  gulp.watch(['lib/**/*', 'bin/**/*', 'package.json'],
//    gulp.series('checkSafe', 'compile'))))

gulp.task('default', gulp.series('build'))
