/* lib/order.js
 * Originally created 11/15/2018 by sapeck
 *
 * Copyright 2018-present sapeck
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
'use strict'

import * as rita from 'rita'
import * as encoding from 'encoding'
import * as numtoWords from 'number-to-words'

export default class Order {
  static order (file) {
    const contents = file.getContents()
    let analyzed = []
    let used = []
    let out = []
    for (let i in contents) {
      analyzed[i] = rita.trimPunctuation(String(encoding.convert(contents[i], 'ASCII')))
      while ((new RegExp('\\.')).test(analyzed[i])) analyzed[i] = analyzed[i].replace(new RegExp('\\.'), '')
      while ((new RegExp('\\?')).test(analyzed[i])) analyzed[i] = analyzed[i].replace(new RegExp('\\?'), '')
      while ((new RegExp('\\!')).test(analyzed[i])) analyzed[i] = analyzed[i].replace(new RegExp('\\!'), '')
      while ((new RegExp('"')).test(analyzed[i])) analyzed[i] = analyzed[i].replace(new RegExp('"'), '')
      analyzed[i] = rita.tokenize(analyzed[i]).slice(-1)[0]
      if (!isNaN(parseInt(analyzed[i], 10))) analyzed[i] = numtoWords.toWords(analyzed[i])
      if (analyzed[i].indexOf('-') > -1) analyzed[i] = analyzed[i].split('-').slice(-1)[0]
      analyzed[i] = analyzed[i].replace(new RegExp('\'s', 'i'), 'ees')
    }
    for (let i = 0; i < analyzed.length; i++) {
      if (!used.includes(i)) {
        let j = 0
        let done = false
        while (j < analyzed.length && !done) {
          if (!used.includes(j) && rita.isRhyme(analyzed[i], analyzed[j])) {
            out.push(contents[i])
            out.push(contents[j])
            used.push(i)
            used.push(j)
            done = true
          } else j++
        }
      }
    }
    return out
  }
}
